#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-splice-plugin
version:              2.3.0.0
visibility:           public
id:                   hls-splice-plugin-2.3.0.0-JOKFM8nHuX48FpHQwTzMzU
key:                  hls-splice-plugin-2.3.0.0-JOKFM8nHuX48FpHQwTzMzU
license:              Apache-2.0
maintainer:
    https://github.com/haskell/haskell-language-server/contributors

author:
    https://github.com/haskell/haskell-language-server/contributors

synopsis:
    HLS Plugin to expand TemplateHaskell Splices and QuasiQuotes

description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  661969c0176d283b6f839896d4c18ab2
exposed:              True
exposed-modules:      Ide.Plugin.Splice Ide.Plugin.Splice.Types
import-dirs:          /usr/lib/ghc-9.6.6/site-local/hls-splice-plugin-2.3.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hls-splice-plugin-2.3.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hls-splice-plugin-2.3.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-splice-plugin
hs-libraries:         HShls-splice-plugin-2.3.0.0-JOKFM8nHuX48FpHQwTzMzU
depends:
    aeson-2.2.2.0-mVpxNJADFA3tVhrw9PzvG base-4.18.2.1 containers-0.6.7
    dlist-1.0-F3vtDhl0dJJ2wapcm5Bnp extra-1.7.16-JQjr8PVpkEB4amK6gdUMOF
    foldl-1.4.18-Hb2va3crH8H7vBsguSu4lL ghc-9.6.6
    ghc-exactprint-1.7.1.0-KZjF9k8x5izE6x14pLdxSE
    ghcide-2.3.0.0-Fl8012fesfY8JAHd1DYtXK
    hls-plugin-api-2.3.0.0-CqqJ1DVds9n4biAp5UxsaC
    hls-refactor-plugin-2.3.0.0-AKU9CcjofBpJQDrbQ49r1t
    lens-5.3.5-KA5gcUGZYMJ4Yj2DW4uyDf
    lsp-2.2.0.0-AApQc3pMEos5GLRJ0i2B8c mtl-2.3.1
    retrie-1.2.3-11Eeu0dXPMwEmeKiFHBUo3
    syb-0.7.4-BzNZTTWYfk9HN4YOl0udkE text-2.0.2 transformers-0.6.1.0
    unliftio-core-0.2.1.0-6sOpIonHj8t5wIbPhWbPHY
    unordered-containers-0.2.21-8KUdGsL7zFhFWAw4aaEQtP

haddock-interfaces:
    /usr/share/doc/haskell-hls-splice-plugin/html/hls-splice-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-splice-plugin/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

